Selecting an active school term
===============================

Some information that is shown in AlekSIS are optionally bound to a specific
time period called *school term*. This includes groups, for example. Other apps
may add more categories of data that are also bound to school terms, such as
lessons or coursebook entries. When viewing or editing these kinds of information,
you need to have an active school term selected. By default, the *current* school
term is selected, but in case you want to access achived data, selecting a past
school term is possible. Selecting school terms can be done in the menu accessible
by clicking the calendar icon in the app bar.

.. image:: ../_static/active_school_term.png
  :width: 100%
  :alt: Active school term selection menu
